import PyBypass as bypasser
import time
import os
import requests
from bs4 import BeautifulSoup
from .pypdl import pypdl_download

def streamtapebye(slink):
    while True:
        bypassed_link = bypasser.bypass(slink, name="streamtape")
        if len(bypassed_link) > 50:
            return bypassed_link
        print("Incomplete URL, retrying in 2 seconds...")
        time.sleep(2)


# url = "https://streamtape.com/v/o6PrJ2B16PSJ14j/Happy_Happy_Cat_but_famous_phone_ringtones.mp4"
# print(streamtapebye(url))

def SaveTape(url, location):
    try:
        direct_url = streamtapebye(url)
        pypdl_download(direct_url, location)
        return location
    except Exception as e:
        print(e)


def tapeimg_url(url):
    try:
        response = requests.get(url)
        response.raise_for_status()
        soup = BeautifulSoup(response.text, 'html.parser')
        og_image_tag = soup.find('meta', {'name': 'og:image'})
        if og_image_tag:
            image_url = og_image_tag['content']
            return image_url
        else:
            return None
    except requests.exceptions.RequestException as e:
            print(f"Error: {e}")
            return None

# print(tapeimg_url("https://streamtape.com/v/o6PrJ2B16PSJ14j/"))

def SavePic(url, directory, filename):
    try:
        os.makedirs(directory, exist_ok=True)
        response = requests.get(url)
        if response.status_code == 200:
            # Save the image
            with open(os.path.join(directory, filename), 'wb') as file:
                file.write(response.content)
            print(f"Image saved successfully at {os.path.join(directory, filename)}")
        else:
            print(f"Failed to download image. Status code: {response.status_code}")
    except Exception as e:
        print(f"An error occurred: {e}")

def SavePicAdv(url, save_dir, num_connections=10):
    try:
        pypdl_download(url, save_dir, num_connections)
    except Exception as e:
        print("e")
        

# SavePicAdv(tapeimg_url("https://streamtape.com/v/o6PrJ2B16PSJ14j/"), "/content/Savedf/HU.jpg")



# urlto = "https://wsrv.nl/?h=320&w=320&q=80&url=" + get_image_url("https://streamtape.com/v/3PpR3x4W7Qiddwk")
# SavePic(urlto, "GoogleColab", "output_imagefrf.jpg")


from torrentp import TorrentDownloader
import os
from .pypdl import pypdl_download

# magnet = "magnet:?xt=urn:btih:8B7E180839C73FA9E1534CAE6CC31079D0A0D059&dn=Wednesday.S01.COMPLETE.720p.NF.WEBRip.x264-GalaxyTV&tr=udp://tracker.coppersurfer.tk:6969/announce&tr=udp://9.rarbg.to:2920/announce&tr=udp://tracker.opentrackr.org:1337&tr=udp://tracker.internetwarriors.net:1337/announce&tr=udp://tracker.leechers-paradise.org:6969/announce&tr=udp://tracker.coppersurfer.tk:6969/announce&tr=udp://tracker.pirateparty.gr:6969/announce&tr=udp://tracker.cyberia.is:6969/announce"

# dir = "/content/torr"

def torrent(magnet_URL, save_dir):
    os.makedirs(save_dir, exist_ok=True)
    torrent_file = TorrentDownloader(magnet_URL, save_dir)
    torrent_file.start_download()

# dest .torrent save 
# save_dir torrent_files save
def torrent_fileurl(file_url, dest, save_dir):
    os.makedirs(save_dir, exist_ok=True)
    try:
        pypdl_download(file_url, dest)
        torrent(dest, save_dir)
    except Exception as e:
        print(e)

# torrent will work same
def torrent_file(file_path, save_dir):
    os.makedirs(save_dir, exist_ok=True)
    try:
        torrent(file_path, save_dir)
    except Exception as e:
        print(e)


import requests
from bs4 import BeautifulSoup
import json
import os
import asyncio
import math

class STClient:
    def __init__(self, username, api_key):
        self.username = username
        self.api_key = api_key
    def auth(self):
        if not all((self.username, self.api_key)):
            raise ValueError("Username, password, and API key must be specified.")
        Api_info = f"https://api.streamtape.com/account/info?login={self.username}&key={self.api_key}"
        try:
            response = requests.get(Api_info)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = response.json()
            a_api = json_data["status"]
            if int(a_api) == 200:
                print("You are authorised")
            else:
                print("Unsuccessful ! Check credentials.")
        except Exception as e:
            print(e)

    def upload_video(self, file_path, folder_id):
        Main_API = f"https://api.streamtape.com/file/ul?login={self.username}&key={self.api_key}&folder={self.folder_id}"
        try:
            response = requests.get(Main_API)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = response.json()
            temp_api = json_data["result"]["url"]
            print("Temp URL:" + temp_api)
            files = {'file': open(file_path, 'rb')}
            response = requests.post(temp_api, files=files)
            response.raise_for_status()
            data_f = response.json()
            download_link = data_f["result"]["url"]
            print(download_link)
            return download_link
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"

    def tapeimg_url(url):
        try:
            response = requests.get(url)
            response.raise_for_status()
            soup = BeautifulSoup(response.text, 'html.parser')
            og_image_tag = soup.find('meta', {'name': 'og:image'})
            if og_image_tag:
                image_url = og_image_tag['content']
                return image_url
            else:
                return None
        except requests.exceptions.RequestException as e:
            print(f"Error: {e}")
            return None

    def add_remote(self, url, folder_id=None, name=None):
        # Main_API = f"https://api.streamtape.com/file/ul?login={self.username}&key={self.api_key}&folder={self.folder_id}"
        if url:
            try:
                Main_API = f"https://api.streamtape.com/remotedl/add?login={self.username}&key={self.api_key}&url={url}"
                payload = {}
                if name:
                    payload["name"] = name
                if folder_id:
                    payload["folder"] = folder_id
                response = requests.get(Main_API, params=payload)
                response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = response.json()
                remote_id = json_data["result"]["id"]
                print("UpID:" + remote_id)
                return remote_id
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give Api Key/url/"

    # check out docs\streamtape_gud\remotestatus.md
    def remote_status(self, id):
        if id:
            try:
                Main_API = f"https://api.streamtape.com/remotedl/status?login={self.username}&key={self.api_key}&id={id}"
                payload = {}
                response = requests.get(Main_API, params=payload)
                response.raise_for_status()  # Raise an exception if the request was not successful
                json_data = response.json()
                # print("UpID:" + json_data)
                return json_data
            except requests.exceptions.RequestException as e:
                print("Request Exception:", e)
                return f"Error {e}"
        else:
            return "Please Give id and what to get"

# idd = "FVAaYwD_ULM"
# json_res = client.remote_status("FVAaYwD_ULM")
# a = client.remote_status("J4Cx7hXoT1s")
# print(a["status"])

def add_parm(dicti, name, value):
    dicti[f"{name}"] = value

# Example usage:
# client = STClient("your_username", "your_api_key")
# client.auth()
# client.upload_video("path_to_video.mp4", "folder_id"



from .streamtape import *
from .getpasscolab import *
from .fileslion import *
from .compressvideo import *
from .streamtapedl import *
from .pypdl import *
from .ulty import *
from .torrent import *
from .GoogleTTS import *